@@ -30,7 +30,7 @@
 @file      stats.hpp
 @brief     collect global statistics - static, partially thread-safe (see below)
 @author    Robert van Engelen - engelen@genivia.com
-@copyright (c) 2019-2022, Robert van Engelen, Genivia Inc. All rights reserved.
+@copyright (c) 2019,2024, Robert van Engelen, Genivia Inc. All rights reserved.
 @copyright (c) BSD-3 License - see LICENSE.txt
 
 Thread-safe functions:
@@ -60,6 +60,10 @@ class Stats {
     reflex::timer_start(timer);
     files = 0;
     dirs = 0;
+    indexed = 0;
+    skipped = 0;
+    changed = 0;
+    added = 0;
     fileno = 0;
     partno = 0;
     lineno = 0;
@@ -79,6 +83,30 @@ class Stats {
     ++dirs;
   }
 
+  // score an indexed file
+  static void score_indexed()
+  {
+    ++indexed;
+  }
+
+  // score an indexed file that was skipped from search
+  static void score_skipped()
+  {
+    ++skipped;
+  }
+
+  // score an indexed file that was changed and searched (stale index file)
+  static void score_changed()
+  {
+    ++changed;
+  }
+
+  // score a non-indexed file that was added and searched (stale index file)
+  static void score_added()
+  {
+    ++added;
+  }
+
   // score matches
   static void score_matches(size_t matches, size_t lines)
   {
@@ -164,6 +192,10 @@ class Stats {
   static reflex::timer_type       timer;   // elapsed wall-clock time in milli seconds (ms)
   static size_t                   files;   // number of files searched, excluding files in archives
   static size_t                   dirs;    // number of directories searched
+  static size_t                   indexed; // number of files found to be indexed
+  static size_t                   skipped; // number of files found to be indexed that were skipped as not matching
+  static size_t                   changed; // number of files found to be indexed but changed (stale index file)
+  static size_t                   added;   // number of files found to be added (stale index file)
   static std::atomic_size_t       fileno;  // number of matching files, excluding files in archives, atomic for GrepWorker::search() update
   static std::atomic_size_t       partno;  // number of matching files, including files in archives, atomic for GrepWorker::search() update
   static std::atomic_size_t       lineno;  // number of lines searched cummulatively
